@@ -2,13 +2,25 @@
 A TiddlyWeb plugin providing a multi-user TiddlyWiki environment.
 """
 
-__version__ = '0.60.0'
+__version__ = '0.61.0'
+
+
+from tiddlyweb.web.handler.recipe import get_tiddlers
+ 
+  
+def friendlywiki(environ, start_response):
+    """
+    Reframe the WSGI environment before internally redirecting
+    to a recipe.
+    """
+    environ['tiddlyweb.type'] = 'text/x-tiddlywiki'
+    return get_tiddlers(environ, start_response)
 
 
 def init(config):
     # These imports must be in init otherwise getting
     # the version number causes cyclic imports to happen.
-    import tiddlywebwiki.manage
+    import tiddlywebplugins.instancer
     import tiddlywebplugins.status
     import tiddlywebplugins.atom
     import tiddlywebplugins.differ
@@ -18,9 +30,13 @@ def init(config):
     from tiddlywebwiki.config import config as twwconfig
 
     merge_config(config, twwconfig)
-    tiddlywebwiki.manage.init(config)
+    tiddlywebplugins.instancer.init(config)
     tiddlywebplugins.status.init(config)
     tiddlywebplugins.atom.init(config)
     tiddlywebplugins.differ.init(config)
     tiddlywebplugins.twimport.init(config)
     tiddlywebplugins.console.init(config)
+
+    if 'selector' in config:
+        if config.get('tiddlywebwiki.friendlywiki', True):
+            config['selector'].add('/{recipe_name:segment}', GET=friendlywiki)
